@@ -10,10 +10,12 @@ handler = logging.StreamHandler(sys.stdout)
 environment_variables_dict = environment_variables.environment_variables_dict
 # log_path = os.getcwd()
 # logs folder
-log_path = environment_variables_dict.get('run_artifacts_path', '')
-if not os.path.isdir(log_path):
-    os.mkdir(log_path)
-fileHandler = logging.FileHandler(filename=f'{log_path}/benchmark_runner.log', mode='w+')
+run_artifacts = environment_variables_dict.get('run_artifacts', '')
+run_artifacts_path = environment_variables_dict.get('run_artifacts_path', '')
+if not os.path.isdir(run_artifacts_path):
+    os.makedirs(run_artifacts, exist_ok=True)
+    os.mkdir(run_artifacts_path)
+fileHandler = logging.FileHandler(filename=f'{run_artifacts_path}/benchmark_runner.log', mode='w+')
 logger.addHandler(handler)
 logger.addHandler(fileHandler)
 
@@ -23,5 +25,5 @@ def get_log_path():
     This method return log path
     :return:
     """
-    return f'{log_path}/benchmark_runner.log'
+    return f'{run_artifacts_path}/benchmark_runner.log'
 
