@@ -5,10 +5,10 @@ class BenchmarkRunnerError(Exception):
     pass
 
 
-class OCSNonInstalled(BenchmarkRunnerError):
+class ODFNonInstalled(BenchmarkRunnerError):
     """
-    This class is error that OCS operator is not installed
+    This class is error that ODF operator is not installed
     """
     def __init__(self):
-        self.message = "OCS is not installed, set 'OCS_PVC' to False"
-        super(OCSNonInstalled, self).__init__(self.message)
+        self.message = "ODF is not installed, set 'ODF_PVC' to False"
+        super(ODFNonInstalled, self).__init__(self.message)
